@@ -9,10 +9,9 @@
 
 const char *progname;
 
-void
-v()
-{
-}
+static void
+vwarnx(const char *err, const char *fmt, va_list args)
+__attribute__((format(printf, 2, 0)));
 
 static void
 vwarnx(const char *err, const char *fmt, va_list args)
